Unit enum

Inheritance
Available extensions

Values

deviceIndependent → const Unit
const Unit("di", 1.0)
centimeters → const Unit
const Unit("cm", 96.0 / 2.54)
millimeters → const Unit
const Unit("mm", 96.0 / 2.54 / 10.0)
inches → const Unit
const Unit("in", 96.0)
points → const Unit
const Unit("pt", 72.0)

Properties

diuPerUnit → double
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
label → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromDeviceIndependent(double n) → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDeviceIndependent(double n) → double
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromString(String s) → Unit

Constants

diuPerCentimeter → const double
diuPerInch → const double
values → const List<Unit>
A constant List of the values in this enum, in order of their declaration.