Annotations class

Inheritance

Constructors

Annotations(ChantContext ctxt, List<String> texts)

Properties

annotations ↔ List<Annotation>
getter/setter pair
bounds ↔ Rect
Relative bounds used to layout the element.
getter/setter pairinherited
boundsForHitTest → Rect
Relative bounds where the element is hit-testable.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
highlight ↔ Color?
Overrides the default color of this element.
getter/setter pairinherited
ignoreBounds ↔ bool
Whether bounds of this element should affect bounds of the parent.
getter/setter pairinherited
lineHeight ↔ double
getter/setter pair
origin ↔ Point
Relative position used to layout the element.
getter/setter pairinherited
padding ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected ↔ bool
Whether the element should be highlighted as selected.
getter/setter pairinherited

Methods

createSvgNode(ChantContext ctxt, [ChantLayoutElement? source]) → XmlElement
Generates SVG representation of the element.
override
createSvgTree(ChantContext ctxt, [ChantLayoutElement? source]) → SvgTreeNode
Generates a lightweight in-memory SVG-like tree.
override
draw(ChantContext ctxt) → void
Paints this the element on Canvas attached to ctxt.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recalculateMetrics(ChantContext ctxt, [bool resetNewLines = true]) → void
toString() → String
A string representation of this object.
inherited
updateBounds([double multiplier = 1.0]) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited