draw method
Paints this the element on Canvas attached to ctxt.
Implementation
@override
void draw(ChantContext ctxt) {
updateBounds();
for (var annotation in annotations) {
annotation.draw(ctxt);
}
updateBounds(-1.0);
}
Paints this the element on Canvas attached to ctxt.
@override
void draw(ChantContext ctxt) {
updateBounds();
for (var annotation in annotations) {
annotation.draw(ctxt);
}
updateBounds(-1.0);
}