ChantLayoutElement class abstract

Base class for all elements in the score.

Implementers

Constructors

ChantLayoutElement()

Properties

bounds ↔ Rect
Relative bounds used to layout the element.
getter/setter pair
boundsForHitTest → Rect
Relative bounds where the element is hit-testable.
no setter
hashCode → int
The hash code for this object.
no setterinherited
highlight ↔ Color?
Overrides the default color of this element.
getter/setter pair
ignoreBounds ↔ bool
Whether bounds of this element should affect bounds of the parent.
getter/setter pair
origin ↔ Point
Relative position used to layout the element.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected ↔ bool
Whether the element should be highlighted as selected.
getter/setter pair

Methods

createSvgNode(ChantContext ctxt, [ChantLayoutElement? source]) → XmlElement
Generates SVG representation of the element.
createSvgTree(ChantContext ctxt, [ChantLayoutElement? source]) → SvgTreeNode
Generates a lightweight in-memory SVG-like tree.
draw(ChantContext ctxt) → void
Paints this the element on Canvas attached to ctxt.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited