ChantNotationElement class
Element that corresponds to a part of sourceGabc notation.
- Inheritance
-
- Object
- ChantLayoutElement
- ChantNotationElement
- Implementers
Constructors
Properties
- allowLineBreakBeforeNext ↔ bool
-
getter/setter pair
-
alText
↔ List<
AboveLinesText> -
getter/setter pair
- bounds ↔ Rect
-
Relative bounds used to layout the element.
getter/setter pairinherited
- boundsForHitTest → Rect
-
Relative bounds where the element is hit-testable.
no setterinherited
- calculatedTrailingSpace ↔ double
-
getter/setter pair
- cssClass ↔ String?
-
getter/setter pair
- elementIndex ↔ int?
-
getter/setter pair
- firstOfParentheses ↔ bool?
-
getter/setter pair
- firstOfSyllable ↔ bool?
-
getter/setter pair
- firstWithNoWidth ↔ ChantNotationElement?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasLyrics → bool
-
no setter
- hasNoWidth ↔ bool
-
getter/setter pair
- highlight ↔ Color?
-
Overrides the default color of this element.
getter/setter pairinherited
- ignoreBounds ↔ bool
-
Whether bounds of this element should affect bounds of the parent.
getter/setter pairinherited
- keepWithNext ↔ bool
-
getter/setter pair
- leadingSpace ↔ double
-
getter/setter pair
- line ↔ ChantLine
-
getter/setter pair
-
lyrics
↔ List<
Lyric> -
getter/setter pair
- needsLayout ↔ bool
-
getter/setter pair
- notationIndex ↔ int
-
getter/setter pair
- origin ↔ Point
-
Relative position used to layout the element.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- score ↔ ChantScore
-
getter/setter pair
- selected ↔ bool
-
Whether the element should be highlighted as selected.
getter/setter pairinherited
- sourceGabc ↔ String
-
getter/setter pair
- sourceIndex ↔ int?
-
getter/setter pair
- sourceLength ↔ int
-
getter/setter pair
- syllable ↔ Syllable
-
getter/setter pair
- trailingSpace ↔ TrailingSpace
-
getter/setter pair
-
translationText
↔ List<
TranslationText> -
getter/setter pair
-
visualizers
→ List<
ChantLayoutElement> -
final
- word ↔ Word
-
getter/setter pair
Methods
-
addVisualizer(
ChantLayoutElement chantLayoutElement) → void -
createSvgNode(
ChantContext ctxt, [ChantLayoutElement? source]) → XmlElement -
Generates SVG representation of the element.
override
-
createSvgTree(
ChantContext ctxt, [ChantLayoutElement? source]) → SvgTreeNode -
Generates a lightweight in-memory SVG-like tree.
override
-
draw(
ChantContext ctxt) → void -
Paints this the element on Canvas attached to
ctxt.override -
finishLayout(
ChantContext ctxt) → void -
getAllLyricsLeft(
) → double -
getAllLyricsRight(
) → double -
getSvgProps(
) → Map< String, dynamic> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
performLayout(
ChantContext ctxt) → void -
prependVisualizer(
ChantLayoutElement chantLayoutElement) → void -
toGabcString(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited