Glyph class final

A glyph defiition composed of shape defined in paths and layout-relevant parameters.

The bounds may differ from actual bounds of the paths.

Constructors

Glyph({String? align, required Rect bounds, required Point origin, required List<GlyphPath> paths})
const

Properties

align → String?
final
bounds → Rect
final
hashCode → int
The hash code for this object.
no setterinherited
origin → Point
final
paths → List<GlyphPath>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited