LedgerLine class

Short line added above or below the staff to notate pitches that fall outside the normal 4‑line range.

Constructors

LedgerLine({required Note element, required Note endElem, required int staffPosition})

Properties

element → Note
final
endElem → Note
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
staffPosition → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited