LedgerLinePos class

Constructors

LedgerLinePos(double x1, double x2, int staffPosition)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
staffPosition ↔ int
getter/setter pair
x1 ↔ double
getter/setter pair
x2 ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited