LiquescentType enum

Inheritance
Mixed-in types
Available extensions

Values

none → const LiquescentType
const LiquescentType(0)
large → const LiquescentType
const LiquescentType(1 << 0)
small → const LiquescentType
const LiquescentType(1 << 1)
ascending → const LiquescentType
const LiquescentType(1 << 2)
descending → const LiquescentType
const LiquescentType(1 << 3)
initioDebilis → const LiquescentType
const LiquescentType(1 << 4)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

hasAnyFlag(int flags) → bool
inherited
hasFlag(Flags flag) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator |(Flags other) → int
inherited

Constants

values → const List<LiquescentType>
A constant List of the values in this enum, in order of their declaration.