LyricArray class

Constructors

LyricArray()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getLeft(List lyricArray) → double
getRight(List<Lyric> lyricArray, [bool presumeConnectorNeeded = false]) → double
hasOnlyOneLyric(List<Lyric> lyricArray) → bool
indexOfLyric(List<Lyric> lyricArray) → int
mergeIn(List<Lyric> lyricArray, List<Lyric> newLyrics) → void
mergeInArray(List<Lyric> lyricArray, List<ChantNotationElement> notations) → void
setNotation(List lyricArray, dynamic notation) → void