MarkupStackFrame class

Helper for parsing nested styling markup.

Constructors

MarkupStackFrame(String tagName, int startIndex, List<Map<String, dynamic>> propertyArray, [String symbol = ''])

Properties

hashCode → int
The hash code for this object.
no setterinherited
properties → Map<String, dynamic>
no setter
propertyArray → List<Map<String, dynamic>>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startIndex → int
final
symbol → String
final
tagName → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

createStackFrame(ChantContext ctxt, String tagName, int startIndex, [Map<String, dynamic> extraProperties = const {}, String symbol = '']) → MarkupStackFrame