Note class

Single note in a neume.

Inheritance

Constructors

Note({Pitch? pitch})

Properties

accent ↔ Accent?
getter/setter pair
alText ↔ AboveLinesText?
getter/setter pair
bounds ↔ Rect
Relative bounds used to layout the element.
getter/setter pairinherited
boundsForHitTest → Rect
Relative bounds where the element is hit-testable.
no setteroverride
braceEnd ↔ BracePoint?
getter/setter pairinherited
braceStart ↔ BracePoint?
getter/setter pair
choralSign ↔ ChoralSign?
getter/setter pair
elementIndex ↔ int?
getter/setter pair
episemata → List<HorizontalEpisema>
final
glyphVisualizer ↔ GlyphVisualizer?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
highlight ↔ Color?
Overrides the default color of this element.
getter/setter pairinherited
ictus ↔ Ictus?
getter/setter pair
ignoreBounds ↔ bool
Whether bounds of this element should affect bounds of the parent.
getter/setter pairinherited
inclinataFlags ↔ int
getter/setter pair
line ↔ ChantLine?
getter/setter pair
liquescent ↔ int
getter/setter pair
morae → List<Mora>
final
neume ↔ Neume?
getter/setter pair
noteIndex ↔ int?
getter/setter pair
origin ↔ Point
Relative position used to layout the element.
getter/setter pairinherited
pitch ↔ Pitch?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected ↔ bool
Whether the element should be highlighted as selected.
getter/setter pairinherited
shape ↔ NoteShape
getter/setter pair
shapeModifiers ↔ int
getter/setter pair
sourceGabc ↔ String
getter/setter pair
sourceIndex ↔ int?
getter/setter pair
sourceLength → int
no setter
staffPosition ↔ int
getter/setter pair
staffPositionOffset ↔ double
getter/setter pair
suppressVirga ↔ bool
getter/setter pair
svgNode ↔ XmlElement?
getter/setter pair

Methods

createSvgNode(ChantContext ctxt, [ChantLayoutElement? source]) → XmlElement
Generates SVG representation of the element.
override
createSvgTree(ChantContext ctxt, [ChantLayoutElement? source]) → SvgTreeNode
Generates a lightweight in-memory SVG-like tree.
override
draw(ChantContext ctxt) → void
Paints this the element on Canvas attached to ctxt.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setGlyph(ChantContext ctxt, GlyphCode glyphCode) → void
toGabcString() → String
Returns gabc source code that, when parsed by Gabc.createNoteFromData, produces an equivalent Note.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited