draw method
Paints this the element on Canvas attached to ctxt.
Implementation
@override
void draw(ChantContext ctxt) {
glyphVisualizer!.bounds = bounds.clone();
glyphVisualizer!.draw(ctxt);
}
Paints this the element on Canvas attached to ctxt.
@override
void draw(ChantContext ctxt) {
glyphVisualizer!.bounds = bounds.clone();
glyphVisualizer!.draw(ctxt);
}