stepToStaffOffset static method

int stepToStaffOffset(
  1. Step step
)

Converts a step to position on the staff (0 is the bottom).

This method should not be used directly as it doesn't account for clef. Use Clef.pitchToStaffPosition instead.

Implementation

static int stepToStaffOffset(Step step) {
  return _stepToStaffPosition[step.value];
}