Point class

Position of an element.

Used internaly by the rendering engine.

Implemented types

Constructors

Point([double x = 0.0, double y = 0.0])
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → double
final
y → double
final

Methods

clone() → Point
copyWith({double? x, double? y}) → Point
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited