Rect class

Bounding box of an element.

Used internaly by the rendering engine.

Implemented types

Constructors

Rect({double x = double.infinity, double y = double.infinity, double width = double.negativeInfinity, double height = double.negativeInfinity})
const
Rect.fromXYWH(double x, double y, double width, double height)
const

Properties

bottom → double
no setter
hashCode → int
The hash code for this object.
no setteroverride
height → double
final
isEmpty → bool
no setter
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
final
x → double
final
y → double
final

Methods

clone() → Rect
contains(Geom other) → bool
containsPoint(Point other) → bool
containsRect(Rect other) → bool
copyWith({double? x, double? y, double? width, double? height}) → Rect
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator +(Rect other) → Rect
operator ==(covariant Rect other) → bool
The equality operator.
override