TranslationText class

Inheritance

Constructors

TranslationText(ChantContext ctxt, String text, ChantNotationElement notation, int sourceIndex)

Properties

bounds ↔ Rect
Relative bounds used to layout the element.
getter/setter pairinherited
boundsForHitTest → Rect
Relative bounds where the element is hit-testable.
no setterinherited
connectorSpan ↔ TextSpan?
getter/setter pairinherited
cssClass ↔ String
getter/setter pairinherited
dominantBaseline ↔ String
getter/setter pairinherited
dropCap ↔ DropCap?
getter/setter pairinherited
endNeume ↔ ChantNotationElement?
getter/setter pair
firstLineMaxWidth ↔ double
getter/setter pairinherited
fontFamily → String Function(ChantContext ctxt)
finalinherited
fontSize → double Function(ChantContext ctxt)
finalinherited
forceConnector ↔ bool?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
highlight ↔ Color?
Overrides the default color of this element.
getter/setter pairinherited
ignoreBounds ↔ bool
Whether bounds of this element should affect bounds of the parent.
getter/setter pairinherited
needsLayout ↔ bool
getter/setter pairinherited
notation → ChantNotationElement
final
numLines ↔ int
getter/setter pairinherited
origin ↔ Point
Relative position used to layout the element.
getter/setter pairinherited
padding ↔ double
getter/setter pair
resize ↔ double?
getter/setter pairinherited
rightAligned ↔ bool?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected ↔ bool
Whether the element should be highlighted as selected.
getter/setter pairinherited
sourceGabc ↔ String
getter/setter pairinherited
sourceIndex ↔ int
getter/setter pairinherited
spans ↔ List<TextSpan>
getter/setter pairinherited
text ↔ String
getter/setter pairinherited
textAnchor ↔ TextAlign
getter/setter pairinherited
textType ↔ TextStyleDefinition
getter/setter pairinherited

Methods

createSvgNode(ChantContext ctxt, [ChantLayoutElement? source]) → XmlElement
Generates SVG representation of the element.
inherited
createSvgTree(ChantContext ctxt, [ChantLayoutElement? source]) → SvgTreeNode
Generates a lightweight in-memory SVG-like tree.
inherited
draw(ChantContext ctxt) → void
Paints this the element on Canvas attached to ctxt.
inherited
generateSpansFromText(ChantContext ctxt, String text) → void
Parses markup in text to fill spans with styled TextSpans.
inherited
getCssClasses() → String
inherited
getExtraStyleProperties(ChantContext ctxt) → Map<String, dynamic>
inherited
getSpanOptions(TextSpan span, ChantContext ctxt, [bool useStyleObject = false]) → Map<String, dynamic>
inherited
getSvgProps() → Map<String, dynamic>
inherited
measureSubstring(ChantContext ctxt, [int? length]) → double
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recalculateMetrics(ChantContext ctxt, [bool resetNewLines = true]) → void
inherited
setMaxWidth(ChantContext ctxt, double maxWidth, [double firstLineMaxWidth = -1]) → void
inherited
toGabcString() → String
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited