Tristropha class

Inheritance

Constructors

Tristropha()

Properties

allowLineBreakBeforeNext ↔ bool
getter/setter pairinherited
alText ↔ List<AboveLinesText>
getter/setter pairinherited
bounds ↔ Rect
Relative bounds used to layout the element.
getter/setter pairinherited
boundsForHitTest → Rect
Relative bounds where the element is hit-testable.
no setterinherited
calculatedTrailingSpace ↔ double
getter/setter pairinherited
cssClass ↔ String?
getter/setter pairinherited
elementIndex ↔ int?
getter/setter pairinherited
firstOfParentheses ↔ bool?
getter/setter pairinherited
firstOfSyllable ↔ bool?
getter/setter pairinherited
firstWithNoWidth ↔ ChantNotationElement?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
hasLyrics → bool
no setterinherited
hasNoWidth ↔ bool
getter/setter pairinherited
highlight ↔ Color?
Overrides the default color of this element.
getter/setter pairinherited
ignoreBounds ↔ bool
Whether bounds of this element should affect bounds of the parent.
getter/setter pairinherited
keepWithNext ↔ bool
getter/setter pairinherited
leadingSpace ↔ double
getter/setter pairinherited
ledgerLines ↔ List<LedgerLine>
getter/setter pairinherited
line ↔ ChantLine
getter/setter pairinherited
lyrics ↔ List<Lyric>
getter/setter pairinherited
needsLayout ↔ bool
getter/setter pairinherited
notationIndex ↔ int
getter/setter pairinherited
notes → List<Note>
finalinherited
origin ↔ Point
Relative position used to layout the element.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score ↔ ChantScore
getter/setter pairinherited
selected ↔ bool
Whether the element should be highlighted as selected.
getter/setter pairinherited
sourceGabc ↔ String
getter/setter pairinherited
sourceIndex ↔ int?
getter/setter pairinherited
sourceLength ↔ int
getter/setter pairinherited
syllable ↔ Syllable
getter/setter pairinherited
trailingSpace ↔ TrailingSpace
getter/setter pairinherited
translationText ↔ List<TranslationText>
getter/setter pairinherited
visualizers → List<ChantLayoutElement>
finalinherited
word ↔ Word
getter/setter pairinherited

Methods

addNote(Note note) → void
inherited
addVisualizer(ChantLayoutElement chantLayoutElement) → void
inherited
build(ChantContext ctxt) → NeumeBuilder
inherited
createSvgNode(ChantContext ctxt, [ChantLayoutElement? source]) → XmlElement
Generates SVG representation of the element.
inherited
createSvgTree(ChantContext ctxt, [ChantLayoutElement? source]) → SvgTreeNode
Generates a lightweight in-memory SVG-like tree.
inherited
draw(ChantContext ctxt) → void
Paints this the element on Canvas attached to ctxt.
inherited
finishLayout(ChantContext ctxt) → void
inherited
getAllLyricsLeft() → double
inherited
getAllLyricsRight() → double
inherited
getSvgProps() → Map<String, dynamic>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performLayout(ChantContext ctxt) → void
override
positionClivisEpisemata(Note firstNote, Note secondNote) → bool
inherited
positionClivisMarkings(Note firstNote, Note secondNote) → bool
inherited
positionClivisMorae(Note firstNote, Note secondNote) → void
inherited
positionEpisemata(Note note, MarkingPositionHint position) → int
inherited
positionEpisemataAbove(Note note) → int
inherited
positionEpisemataBelow(Note note) → int
inherited
positionInclinataMorae(List<Note> notes) → void
inherited
positionMarkings() → void
override
positionPodatusEpisemata(Note bottomNote, Note topNote) → void
inherited
positionPodatusMarkings(Note bottomNote, Note topNote) → void
inherited
positionPodatusMorae(Note bottomNote, Note topNote) → void
inherited
positionPorrectusFlexusMarkings(Note first, Note second, Note third, Note fourth) → void
inherited
positionPorrectusMarkings(Note firstNote, Note secondNote, Note thirdNote) → void
inherited
positionTorculusMarkings(Note firstNote, Note secondNote, Note thirdNote) → bool
inherited
prependVisualizer(ChantLayoutElement chantLayoutElement) → void
inherited
requiresLedgerLine(ChantContext ctxt) → List<LedgerLine>
inherited
resetDependencies() → void
inherited
toGabcNotationString() → String
inherited
toGabcString() → String
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited