internals library

Classes

AboveLinesText
Accent
Accidental
Ancus
Annotation
Annotations
Apostropha
Bivirga
CanvasPathBuilder
Mimic HTML5 canvas
ChantLayoutElement
Base class for all elements in the score.
ChantLine
A single line in ChantScore.
ChantNotationElement
Element that corresponds to a part of sourceGabc notation.
ChiRhoClef
ChoralSign
Little text above a note.
Clef
Clef base class.
Climacus
Clivis
CondensableSpace
Helper to calculate even distances between justified neumes.
Distropha
Divider
DoClef
DominicanBar
DoubleBar
DropCap
FaClef
FullBar
Geom
Glyph
A glyph defiition composed of shape defined in paths and layout-relevant parameters.
GlyphPath
A path definition in SVG syntax.
HalfBar
HorizontalEpisema
Ictus
InsertionCursor
LedgerLine
Short line added above or below the staff to notate pitches that fall outside the normal 4‑line range.
LedgerLinePos
Lyric
LyricArray
MarkupStackFrame
Helper for parsing nested styling markup.
Mora
Neume
Neumes base class
NeumeBuilder
Note
Single note in a neume.
Oriscus
PesQuassus
PesSubpunctis
Pitch
Musical pitch.
Podatus
Point
Position of an element.
Porrectus
PorrectusFlexus
PunctaInclinata
Punctum
QuarterBar
Rect
Bounding box of an element.
Salicus
SalicusFlexus
Scalar
A scalar value expressed in units.
Scandicus
ScandicusFlexus
Subtitle
Supertitle
TextElement
Base class for text elements.
TextLeftRight
TextSpan
A chunk of TextElement with uniform text style.
Title
TitleTextElement
Torculus
TorculusResupinus
TorculusResupinusFlexus
TranslationText
TrebleClef
Tristropha
Trivirga
Virga
Virgula

Enums

AccidentalType
GlyphCode
Glyphs that can be rendered by GlyphVisualizer.
HorizontalEpisemaAlignment
LiquescentType
LyricType
NoteShape
NoteShapeModifiers
Step
Steps of the musical scale.
Unit

Mixins

Flags
Bitfield capability for enums.

Constants

glyphs → const Map<GlyphCode, Glyph>
All glyph definitions.
greextraGlyphs → const Map<String, String>

Properties

defaultDoClef → DoClef
final

Functions

combineFlags(int current, Flags flag) → int
Combines a Flags enum value with an int (result of | operator) and returns the combined int value. Used for setting flags on Note fields.
escapeForTspan(String string) → String
getCssForProperties(Map<String, dynamic> properties) → String
hasAnyFlag(int flags, int mask) → bool
Returns true if flags (an int) has any of the given mask bits set.
hasFlag(int flags, Flags flag) → bool
Returns true if flags (an int) has the given flag set.
parseColor(String? value) → Color?
Parses a CSS/SVG hex color (#RGB, #RRGGBB, or #RRGGBBAA). Supported named colors: red → ChantColors.rubric, black → ChantColors.nigric.
parseSvgPath(String data) → Path
Parses an SVG path data string into a Path.

Typedefs

ElementNodeMaker<T> = T Function(ChantLayoutElement e, ChantContext c)