Accent class
- Inheritance
-
- Object
- ChantLayoutElement
- Accent
Constructors
- Accent(ChantContext ctxt, Note note, {GlyphCode glyphCode = GlyphCode.acuteAccent})
Properties
- align ↔ String?
-
getter/setter pairinherited
- bounds ↔ Rect
-
Relative bounds used to layout the element.
getter/setter pairinherited
- boundsForHitTest → Rect
-
Relative bounds where the element is hit-testable.
no setterinherited
- glyph ↔ Glyph?
-
getter/setter pairinherited
- glyphCode ↔ GlyphCode?
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlight ↔ Color?
-
Overrides the default color of this element.
getter/setter pairinherited
- ignoreBounds ↔ bool
-
Whether bounds of this element should affect bounds of the parent.
getter/setter pairinherited
- note → Note
-
final
- origin ↔ Point
-
Relative position used to layout the element.
getter/setter pairinherited
- parent ↔ ChantLayoutElement
-
getter/setter pairinherited
- positionHint → MarkingPositionHint
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected ↔ bool
-
Whether the element should be highlighted as selected.
getter/setter pairinherited
Methods
-
createSvgNode(
ChantContext ctxt, [ChantLayoutElement? source]) → XmlElement -
Generates SVG representation of the element.
inherited
-
createSvgTree(
ChantContext ctxt, [ChantLayoutElement? source]) → SvgTreeNode -
Generates a lightweight in-memory SVG-like tree.
inherited
-
draw(
ChantContext ctxt) → void -
Paints this the element on Canvas attached to
ctxt.inherited -
getDefProps(
ChantContext ctxt) → Map< String, String> -
inherited
-
getSvgAttributes(
ChantContext ctxt, [ChantLayoutElement? source]) → Map< String, dynamic> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
performLayout(
ChantContext ctxt) → void -
registerGlyph(
ChantContext ctxt) → void -
inherited
-
setGlyph(
ChantContext ctxt, GlyphCode glyphCode) → void -
inherited
-
setStaffPosition(
ChantContext ctxt, int staffPosition) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited