CanvasPathBuilder class
Mimic HTML5 canvas
Constructors
Properties
- color ↔ Color
-
getter/setter pair
-
dashPattern
↔ List<
double> ? -
Dash lengths alternating on/off, in logical pixels.
nullor empty means a solid stroke.getter/setter pair - debugDashPath → Path
-
The path actually drawn by stroke (dash segments or the full path).
Exposed for testing.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strokeWidth ↔ double
-
getter/setter pair
Methods
-
close(
) → void -
lineTo(
double x, double y) → void -
lineToRect(
Rect rect) → void -
Draws a line to the top-left corner of
rect. -
moveTo(
double x, double y) → void -
moveToRect(
Rect rect) → void -
Starts the path at the top-left corner of
rect. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rect(
Rect rect) → void -
Traces the outline of
rectas a closed subpath, starting at its top-left corner. -
stroke(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited