ChantLine class
A single line in ChantScore.
- Inheritance
-
- Object
- ChantLayoutElement
- ChantLine
Constructors
- ChantLine(ChantScore score)
Properties
- altLineBaseline ↔ double
-
getter/setter pair
- altLineHeight ↔ double
-
getter/setter pair
- bounds ↔ Rect
-
Relative bounds used to layout the element.
getter/setter pairinherited
- boundsForHitTest → Rect
-
Relative bounds where the element is hit-testable.
no setterinherited
-
braces
↔ List<
ChantLayoutElement> -
getter/setter pair
-
condensableSpaces
↔ List<
CondensableSpace> -
getter/setter pair
- custos ↔ Custos?
-
getter/setter pair
- debugHasCachedPicture → bool
-
Whether a cached picture exists for the current paint state.
Exposed for tests.
no setter
- debugPictureSignature → Object?
-
Signature of the current cached picture, or null when uncached.
Exposed for tests.
no setter
- elementIndex ↔ int
-
getter/setter pair
- extraTextOnlyHeight ↔ double
-
getter/setter pair
- extraTextOnlyIndex ↔ int?
-
getter/setter pair
- extraTextOnlyLyricIndex ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlight ↔ Color?
-
Overrides the default color of this element.
getter/setter pairinherited
- ignoreBounds ↔ bool
-
Whether bounds of this element should affect bounds of the parent.
getter/setter pairinherited
- insertionCursor ↔ InsertionCursor?
-
getter/setter pair
- insertionPreview ↔ ChantLayoutElement?
-
getter/setter pair
- justify ↔ bool
-
getter/setter pair
-
lastLyrics
↔ List<
Lyric> -
getter/setter pair
-
lastLyricsBeforeTextOnly
↔ List<
Lyric> ? -
getter/setter pair
-
ledgerLines
↔ List<
LedgerLinePos> -
getter/setter pair
- lyricLineBaseline ↔ double
-
getter/setter pair
- lyricLineHeight ↔ double
-
getter/setter pair
- maxNumNotationsOnLine ↔ int?
-
getter/setter pair
- notationBounds ↔ Rect
-
getter/setter pair
-
notations
→ Iterable<
ChantNotationElement> -
no setter
- notationsStartIndex ↔ int
-
getter/setter pair
- numAltLines ↔ int
-
getter/setter pair
- numLyricLines ↔ int
-
getter/setter pair
- numNotationsOnLine ↔ int
-
getter/setter pair
- numTranslationLines ↔ int
-
getter/setter pair
- origin ↔ Point
-
Relative position used to layout the element.
getter/setter pairinherited
- paddingLeft ↔ double
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- score → ChantScore
-
final
- selected ↔ bool
-
Whether the element should be highlighted as selected.
getter/setter pairinherited
- spaceAfterNotations ↔ double
-
getter/setter pair
- spaceBetweenTextTracks ↔ double
-
getter/setter pair
- staffLeft ↔ double
-
getter/setter pair
- staffRight ↔ double
-
getter/setter pair
- staffSpaces → int
-
no setter
- startingClef ↔ Clef?
-
getter/setter pair
- toJustify ↔ List
-
getter/setter pair
- translationLineBaseline ↔ double
-
getter/setter pair
- translationLineHeight ↔ double
-
getter/setter pair
Methods
-
bisectNotationAtX(
double x, {bool useMidpoint = true}) → ChantNotationElement -
buildFromChantNotationIndex(
ChantContext ctxt, int newElementStart, double width) → void -
centerDividers(
) → void -
createSvgNode(
ChantContext ctxt, [ChantLayoutElement? source, double top = 0]) → XmlElement -
Generates SVG representation of the element.
override
-
createSvgTree(
ChantContext ctxt, [ChantLayoutElement? source, double top = 0]) → SvgTreeNode -
Generates a lightweight in-memory SVG-like tree.
override
-
disposePictureCache(
) → void - Discards the cached picture, if any.
-
draw(
ChantContext ctxt) → void -
Paints this the element on Canvas attached to
ctxt.override -
findNeumesToJustify(
List< Lyric> prevLyrics) → ChantNotationElement? -
finishLayout(
ChantContext ctxt) → void -
generateCurlyBraceDrawable(
ChantContext ctxt, double x1, double x2, double y, bool isAbove) → String -
getInnerNodes<
T> (ChantContext ctxt, {double top = 0, required NodeMaker< T> quickSvg, required ElementNodeMaker<T> element}) → List<T> -
getWhitespaceOnRight(
ChantContext ctxt) → double -
handleEndBrace(
ChantContext ctxt, ChantLayoutElement note, int i) → void -
justifyElements(
ChantContext ctxt, bool doJustify, List< CondensableSpace> condensableSpaces) → void -
layoutInsertionCursor(
ChantContext ctxt) → InsertionCursor? -
layoutInsertionPreview(
ChantContext ctxt) → ChantLayoutElement? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
performLayout(
ChantContext ctxt) → void -
positionNotationElement(
ChantContext ctxt, List< Lyric> prevLyrics, ChantNotationElement prev, ChantNotationElement curr, double rightNotationBoundary, [List<CondensableSpace> ? condensableSpaces]) → bool -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited