model property
Reference to the original definition of this clef.
Clefs are repeaded at the beginning of every line. Each line-starting clef has a reference to the original one.
Implementation
Clef? model;
Reference to the original definition of this clef.
Clefs are repeaded at the beginning of every line. Each line-starting clef has a reference to the original one.
Clef? model;