NeumeBuilder class
Methods
-
advanceBy(double xValue)
→ void
-
-
lineFrom(Note note)
→ void
-
Used to start a hanging line on the left of the next note
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
noteAt(Note note, GlyphCode glyph, {bool withLineTo = true})
→ void
-
Add a note, with a connecting line on the left if we have one
-
toString()
→ String
-
A string representation of this object.
inherited
-
virgaAt(Note note, {bool withLineTo = true})
→ void
-
A special form of noteAt that creates a virga
Uses a punctum cuadratum and a line rather than the virga glyphs
-
withClivis({required Note upper, required Note lower})
→ void
-
-
withClivisLower(Note lower)
→ void
-
-
withClivisUpper({required Note upper, Note? lower, GlyphCode glyph = GlyphCode.punctumQuadratum})
→ void
-
-
withInclinata(List<Note> notes)
→ void
-
Lays out a sequence of notes that are inclinata (e.g., climacus, pes subpunctis)
-
withLineEndingAt(Note note)
→ void
-
For terminating hanging lines with no lower notes
-
withPodatus({required Note lower, required Note upper})
→ void
-
-
withPorrectusSwash({required Note start, required Note end})
→ void
-