Step enum
Steps of the musical scale.
Values
- ut → const Step
-
const Step(0) - du → const Step
-
const Step(1) - re → const Step
-
const Step(2) - me → const Step
-
const Step(3) - mi → const Step
-
const Step(4) - fa → const Step
-
const Step(5) - fu → const Step
-
const Step(6) - so → const Step
-
const Step(7) - __invalid → const Step
-
const Step(8) - la → const Step
-
const Step(9) - te → const Step
-
const Step(10) - ti → const Step
-
const Step(11)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited