TextSpan class
A chunk of TextElement with uniform text style.
Constructors
Properties
-
activeTags
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
final
- newLine ↔ int
-
getter/setter pair
-
properties
→ Map<
String, dynamic> -
no setter
-
propertyArray
→ List<
Map< String, dynamic> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text ↔ String
-
The text content of this span.
getter/setter pair
- xOffset ↔ double?
-
getter/setter pair
Methods
-
buildParagraph(
ChantContext ctxt, Map< String, dynamic> extraProps, TextAlign textAlign, [double? resize]) → Paragraph - Builds and caches the Paragraph for this span.
-
clone(
) → TextSpan - Create a deep copy of this span.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toGabcString(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getTextStyle(
Map< String, dynamic> props, ChantContext ctxt, double? resize) → TextStyle -
Computes the effective TextStyle for given CSS-ish styling
props.